#
# Cookbook Name:: kosmos-base
# Recipe:: letsencrypt
#
# The MIT License (MIT)
#
# Copyright:: 2019, Kosmos Developers
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

unless platform?('ubuntu')
  raise "This recipe only supports Ubuntu installs"
end

if node[:platform_version].to_f < 20.04
  apt_repository "certbot" do
    uri "ppa:certbot/certbot"
  end
  package "certbot"
else
  bash "install_certbot_snap" do
    code "snap install --classic certbot"
  end
  # TODO switch to snap_package resource when they fix it
  # snap_package "certbot" do
  #   options "--classic"
  # end
end

%w(deploy post pre).each do |subdir|
  directory "/etc/letsencrypt/renewal-hooks/#{subdir}" do
    recursive true
    mode 0755
    owner "root"
    group "root"
  end
end

# TODO check if nginx is installed/running on the node
file "/etc/letsencrypt/renewal-hooks/deploy/nginx" do
  content <<-EOF
#!/usr/bin/env bash
# Reloading nginx is enough to read the new certificates
systemctl reload nginx
  EOF
  mode 0755
  owner "root"
  group "root"
end

# include_recipe 'kosmos-base::systemd_emails'

# TODO Check the deployed certs expiration dates instead of overwriting supplied systemd services
# Overwrite the systemd service to add email notifications on failures
# cookbook_file "/lib/systemd/system/certbot.service" do
#   source "certbot.service"
#   notifies :run, "execute[systemctl daemon-reload]", :delayed
# end
# execute "systemctl daemon-reload" do
#   command "systemctl daemon-reload"
#   action :nothing
# end
