#
# Cookbook:: kosmos-bitcoin
# Recipe:: snapd
#
# The MIT License (MIT)
#
# Copyright:: 2020, Kosmos Developers
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

# FIXME: Switch to the snap_package resource when it gets fixed:
# https://github.com/chef/chef/issues/8827
execute "snap install bitcoin-core --channel=latest/stable"

bitcoin_user    = node['bitcoin']['username']
bitcoin_group   = node['bitcoin']['usergroup']
bitcoin_datadir = node['bitcoin']['datadir']
bitcoin_snapdir = "/home/#{bitcoin_user}/snap/bitcoin-core/common/.bitcoin"

user bitcoin_user do
  manage_home true
  shell "/bin/bash"
end

directory bitcoin_datadir do
  owner bitcoin_user
  group bitcoin_group
  mode '0755'
  recursive true
  action :create
end

bitcoin_config = node['bitcoin']['conf'].merge({
  rpcpassword: credentials["rpcpassword"]
})

template "#{bitcoin_datadir}/bitcoin.conf" do
  owner bitcoin_user
  group bitcoin_group
  variables conf: bitcoin_config,
            mainnet_conf: node['bitcoin']['mainnet_conf'],
            testnet_conf: node['bitcoin']['testnet_conf'],
            regtest_conf: node['bitcoin']['regtest_conf']
  action :create
  notifies :restart, "systemd_unit[bitcoind.service]", :delayed
end

directory bitcoin_snapdir do
  owner bitcoin_user
  group bitcoin_group
  mode '0750'
  recursive true
  action :create
end

execute "chown -R #{bitcoin_user}:#{bitcoin_group} /home/#{bitcoin_user}/snap"

mount bitcoin_snapdir do
  device bitcoin_datadir
  fstype 'none'
  options 'bind'
  action [:mount]
end

systemd_unit 'bitcoind.service' do
  content({
    Unit: {
      Description: 'Bitcoin Core daemon',
      Documentation: ['https://bitcoincore.org'],
      After: 'network.target'
    },
    Service: {
      User: bitcoin_user,
      Type: 'exec',
      ExecStart: '/snap/bin/bitcoin-core.daemon',
      PIDFile: "#{bitcoin_snapdir}/bitcoind.pid",
      Restart: 'on-failure',
    },
    Install: {
      WantedBy: 'multi-user.target'
    }
  })
  verify false
  triggers_reload true
  action [:create, :enable, :start]
end
