#
# Cookbook Name:: kosmos-ipfs
# Recipe:: public_gateway
#
# The MIT License (MIT)
#
# Copyright:: 2019, Kosmos Developers
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

include_recipe "kosmos-nginx"

domain = node["kosmos-ipfs"]["nginx"]["domain"]

template "#{node['nginx']['dir']}/sites-available/#{domain}" do
  source "nginx_conf_#{domain}.erb"
  owner 'www-data'
  mode 0640
  variables server_name:            domain,
            ssl_cert:               "/etc/letsencrypt/live/#{domain}/fullchain.pem",
            ssl_key:                "/etc/letsencrypt/live/#{domain}/privkey.pem",
            ipfs_api_port:          node['kosmos-ipfs']['nginx']['api_port'],
            ipfs_gateway_port:      node['kosmos-ipfs']['nginx']['gateway_port'],
            ipfs_external_api_port: node['kosmos-ipfs']['nginx']['external_api_port']

  notifies :reload, 'service[nginx]', :delayed
end

nginx_site domain do
  action :enable
end

nginx_certbot_site domain

unless node.chef_environment == "development"
  include_recipe "kosmos-ipfs::firewall_public_gateway"
end
